==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/DstChoiceGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.DstChoice;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping dst-choice-grouping {
 *   choice dst-choice {
 *     case dst-nx-reg-case {
 *       uses nxm-nx-reg-grouping;
 *     }
 *     case dst-nx-tun-id-case {
 *       uses nxm-nx-tun-id-grouping;
 *     }
 *     case dst-of-mpls-label-case {
 *       uses oxm-of-mpls-label-grouping;
 *     }
 *     case dst-of-metadata-case {
 *       uses oxm-of-metadata-grouping;
 *     }
 *     case dst-nx-arp-sha-case {
 *       uses nxm-nx-arp-sha-grouping;
 *     }
 *     case dst-nx-arp-tha-case {
 *       uses nxm-nx-arp-tha-grouping;
 *     }
 *     case dst-of-arp-op-case {
 *       uses nxm-of-arp-op-grouping;
 *     }
 *     case dst-of-arp-spa-case {
 *       uses nxm-of-arp-spa-grouping;
 *     }
 *     case dst-of-arp-tpa-case {
 *       uses nxm-of-arp-tpa-grouping;
 *     }
 *     case dst-nx-of-in-port-case {
 *       uses nxm-of-in-port-grouping;
 *     }
 *     case dst-nx-tun-ipv4-dst-case {
 *       uses nxm-nx-tun-ipv4-dst-grouping;
 *     }
 *     case dst-nx-tun-ipv4-src-case {
 *       uses nxm-nx-tun-ipv4-src-grouping;
 *     }
 *     case dst-of-eth-src-case {
 *       uses nxm-of-eth-src-grouping;
 *     }
 *     case dst-of-eth-dst-case {
 *       uses nxm-of-eth-dst-grouping;
 *     }
 *     case dst-nx-nsp-case {
 *       uses nxm-nx-nsp-grouping;
 *     }
 *     case dst-nx-nsi-case {
 *       uses nxm-nx-nsi-grouping;
 *     }
 *     case dst-nx-nshc-1-case {
 *       uses nxm-nx-nshc-1-grouping;
 *     }
 *     case dst-nx-nshc-2-case {
 *       uses nxm-nx-nshc-2-grouping;
 *     }
 *     case dst-nx-nshc-3-case {
 *       uses nxm-nx-nshc-3-grouping;
 *     }
 *     case dst-nx-nshc-4-case {
 *       uses nxm-nx-nshc-4-grouping;
 *     }
 *     case dst-of-ip-src-case {
 *       uses nxm-of-ip-src-grouping;
 *     }
 *     case dst-of-ip-dst-case {
 *       uses nxm-of-ip-dst-grouping;
 *     }
 *     case dst-nx-ipv6-src-case {
 *       uses nxm-nx-ipv6-src-grouping;
 *     }
 *     case dst-nx-ipv6-dst-case {
 *       uses nxm-nx-ipv6-dst-grouping;
 *     }
 *     case dst-of-icmp-type-case {
 *       uses nxm-of-icmp-type-grouping;
 *     }
 *     case dst-nx-nsh-flags-case {
 *       uses nxm-nx-nsh-flags-grouping;
 *     }
 *     case dst-nx-nsh-ttl-case {
 *       uses nxm-nx-nsh-ttl-grouping;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/dst-choice-grouping</i>
 *
 */
public interface DstChoiceGrouping
    extends
    DataObject
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("dst-choice-grouping");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.DstChoice</code> <code>dstChoice</code>, or <code>null</code> if not present
     */
    @Nullable DstChoice getDstChoice();

}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/DstChoiceGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.DstChoice;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping dst-choice-grouping {
 *   choice dst-choice {
 *     case dst-nx-reg-case {
 *       uses nxm-nx-reg-grouping;
 *     }
 *     case dst-nx-tun-id-case {
 *       uses nxm-nx-tun-id-grouping;
 *     }
 *     case dst-of-mpls-label-case {
 *       uses oxm-of-mpls-label-grouping;
 *     }
 *     case dst-of-metadata-case {
 *       uses oxm-of-metadata-grouping;
 *     }
 *     case dst-nx-arp-sha-case {
 *       uses nxm-nx-arp-sha-grouping;
 *     }
 *     case dst-nx-arp-tha-case {
 *       uses nxm-nx-arp-tha-grouping;
 *     }
 *     case dst-of-arp-op-case {
 *       uses nxm-of-arp-op-grouping;
 *     }
 *     case dst-of-arp-spa-case {
 *       uses nxm-of-arp-spa-grouping;
 *     }
 *     case dst-of-arp-tpa-case {
 *       uses nxm-of-arp-tpa-grouping;
 *     }
 *     case dst-nx-of-in-port-case {
 *       uses nxm-of-in-port-grouping;
 *     }
 *     case dst-nx-tun-ipv4-dst-case {
 *       uses nxm-nx-tun-ipv4-dst-grouping;
 *     }
 *     case dst-nx-tun-ipv4-src-case {
 *       uses nxm-nx-tun-ipv4-src-grouping;
 *     }
 *     case dst-of-eth-src-case {
 *       uses nxm-of-eth-src-grouping;
 *     }
 *     case dst-of-eth-dst-case {
 *       uses nxm-of-eth-dst-grouping;
 *     }
 *     case dst-nx-nsp-case {
 *       uses nxm-nx-nsp-grouping;
 *     }
 *     case dst-nx-nsi-case {
 *       uses nxm-nx-nsi-grouping;
 *     }
 *     case dst-nx-nshc-1-case {
 *       uses nxm-nx-nshc-1-grouping;
 *     }
 *     case dst-nx-nshc-2-case {
 *       uses nxm-nx-nshc-2-grouping;
 *     }
 *     case dst-nx-nshc-3-case {
 *       uses nxm-nx-nshc-3-grouping;
 *     }
 *     case dst-nx-nshc-4-case {
 *       uses nxm-nx-nshc-4-grouping;
 *     }
 *     case dst-of-ip-src-case {
 *       uses nxm-of-ip-src-grouping;
 *     }
 *     case dst-of-ip-dst-case {
 *       uses nxm-of-ip-dst-grouping;
 *     }
 *     case dst-nx-ipv6-src-case {
 *       uses nxm-nx-ipv6-src-grouping;
 *     }
 *     case dst-nx-ipv6-dst-case {
 *       uses nxm-nx-ipv6-dst-grouping;
 *     }
 *     case dst-of-icmp-type-case {
 *       uses nxm-of-icmp-type-grouping;
 *     }
 *     case dst-nx-nsh-flags-case {
 *       uses nxm-nx-nsh-flags-grouping;
 *     }
 *     case dst-nx-nsh-ttl-case {
 *       uses nxm-nx-nsh-ttl-grouping;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/dst-choice-grouping</i>
 *
 */
public interface DstChoiceGrouping
    extends
    DataObject
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("dst-choice-grouping");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.DstChoice</code> <code>dstChoice</code>, or <code>null</code> if not present
     */
    @Nullable DstChoice getDstChoice();

}
